@@ -9,6 +9,7 @@ class Task:
 
     def __init__(self, func=None, weight=1, order=0, comment="", system=False):
         self.name = "noname"
+        self.title = "noname"
         self.timer = Task.DEFAULT
         self.func = func
         self.weight = weight
@@ -18,6 +19,8 @@ class Task:
 
     def set_name(self, name):
         self.name = name
+    def set_title(self, title):
+        self.title = title
 
     def set_test_plan(self, test_plan):
         self.test_plan = test_plan
