@@ -6,6 +6,7 @@ import sys
 import time
 import traceback
 from asyncio.locks import BoundedSemaphore
+from random import randint
 
 from lemmings.task_set_run import TaskSetRun
 from lemmings.utils import _num, duration2sec, exception_with_line
@@ -27,6 +28,7 @@ class Worker:
         self.ansi_colors = ansi_colors
 
         self.title = f"{self.name}[{self.id}]"
+        self.process_name = f"{self.name}_{self.id}"
         self.max_in_parallel = max_in_parallel
 
         # will be init in execute (in child processes):
@@ -36,6 +38,8 @@ class Worker:
 
     def set_title(self, title):
         self.title = title
+    def set_process_name(self, process_name):
+        self.process_name = process_name
 
     def set_shared(self, shared_state):
         self.shared_state = shared_state
@@ -44,21 +48,28 @@ class Worker:
         self.stat = stat
 
     async def run_task(self, offset, task):
-        await asyncio.sleep(duration2sec(offset))
-        start = time.time()
+        begin = time.time()
+        d = duration2sec(offset)
+        await asyncio.sleep(d)
+        delay = time.time() - begin - d
+        if delay > 1: # difference more than 1 sec
+            logging.warning(f"running late task {task.title} [delay: {delay:.2f}], scheduled at {d:.2f} | {offset}")
 
         def print_stat(prefix, print=True, comment="", success=False, failed=False):
-            succ = Color.mark(Color.green, _num(self.stat.executed))
-            fail = Color.mark(Color.red, _num(self.stat.failed))
-            if success:
-                succ = Color.bold(succ)
-            if failed:
-                fail = Color.bold(fail)
+            succ = _num(self.stat.executed)
+            fail = _num(self.stat.failed)
+            # succ = Color.mark(Color.green, _num(self.stat.executed))
+            # fail = Color.mark(Color.red, _num(self.stat.failed))
+            # if success:
+            #     succ = Color.bold(succ)
+            # if failed:
+            #     fail = Color.bold(fail)
             total = _num(self.stat.total)
             if task.comment:
                 comment = task.comment + " " + comment
             if print:
-                self.log(f"{prefix:5}> {succ} / {fail} / {total} in {time.time() - start:.2f} sec", comment)
+                global program_start
+                self.log(f"{prefix:5}> {succ} / {fail} / {total} in {time.time() - program_start:.2f} sec", comment)
 
         try:
             async with self.semaphore:
@@ -72,7 +83,7 @@ class Worker:
                 self.stat.fail()
             print_stat(FAIL, comment=exception_with_line(e), failed=True)
             if self.debug:
-                logging.exception(f"Exception during run_task")
+                logging.exception(f"Exception during run_task {task.title}")
 
     def execute(self):
         Color.enable(self.ansi_colors)
@@ -124,7 +135,7 @@ class Worker:
         global program_start
         if comment:
             comment = " | " + Color.cursive(comment)
-        logging.info(f"[worker={self.name}][offset:{(time.time() - program_start):7.3f}] {msg} {comment}")
+        logging.info(f"[worker={self.process_name}][offset:{(time.time() - program_start):7.3f}] {msg} {comment}")
 
     def __str__(self):
         return self.title
